@@ -18,8 +18,8 @@ from xlsx_lib.domain.electronic.electronic_sheet import ElectronicSheet
 from xlsx_lib.domain.generic_replacements.generic_replacement_sheet import GenericReplacementsSheet
 from xlsx_lib.domain.generic_replacements.replacement import Replacement
 
-from xlsx_lib.domain.tightening_torques.tightening_torques_sheet import TighteningTorquesSheet
-from xlsx_lib.domain.tightening_torques.component import Component
+from xlsx_lib.domain.tightening_specifications.tightening_specifications_sheet import TighteningSpecificationsSheet
+from xlsx_lib.domain.tightening_specifications.specification_element import SpecificationElement
 
 sheetnames_relationships = {
     "MOT": Sheetnames.ENGINE,
@@ -31,39 +31,52 @@ sheetnames_relationships = {
 
 
 class MotorcycleModelWorkbook:
-    motorcycle_model: MotorcycleModel
+    motorcycle_model: Optional[MotorcycleModel]
 
-    def __init__(self, filename: any, directory: Optional[str] = None):
+    def __init__(
+            self,
+            filename: any
+    ):
         workbook: Workbook = load_workbook(filename=filename)
 
+        model_name: str = filename[filename.rfind("/") + 1:filename.rfind(".")] \
+            .rstrip() \
+            .replace("FICHA ", "")
+
         generic_replacements: Optional[List[Replacement]] = None
         electronic_elements: Optional[List[ElectronicElement]] = None
-        components_screws_tightening_torques: Optional[List[Component]] = None
+        tightening_specifications: Optional[List[SpecificationElement]] = None
         engine_sections: Optional[List[EngineSection]] = None
         frame_elements: Optional[List[FrameElement]] = None
 
-        for sheetname in [key for key in workbook.sheetnames if key in sheetnames_relationships]:
-            if sheetnames_relationships[sheetname] == Sheetnames.ENGINE:
-                engine_sections = \
-                    EngineSheet(worksheet=workbook[sheetname]).get_electronic_elements()
-            elif sheetnames_relationships[sheetname] == Sheetnames.GENERIC_REPLACEMENTS:
+        for sheetname in [key for key in workbook.sheetnames
+                          if key in sheetnames_relationships]:
+            if Sheetnames.ENGINE == sheetnames_relationships[sheetname]:
+                engine_sheet: EngineSheet = EngineSheet(worksheet=workbook[sheetname])
+                engine_sections: List[EngineSection] = engine_sheet.engine_sections
+                # TODO: Check if EngineSheet have distribution
+
+            elif Sheetnames.GENERIC_REPLACEMENTS == sheetnames_relationships[sheetname]:
                 generic_replacements = \
                     GenericReplacementsSheet(worksheet=workbook[sheetname]).get_generic_replacements()
-            elif sheetnames_relationships[sheetname] == Sheetnames.ELECTRONIC:
+
+            elif Sheetnames.ELECTRONIC == sheetnames_relationships[sheetname]:
                 electronic_elements = \
                     ElectronicSheet(worksheet=workbook[sheetname]).get_electronic_elements()
-            elif sheetnames_relationships[sheetname] == Sheetnames.TIGHTENING_TORQUES:
-                components_screws_tightening_torques = \
-                    TighteningTorquesSheet(worksheet=workbook[sheetname]).get_components_screws_tightening_torques()
-            elif sheetnames_relationships[sheetname] == Sheetnames.FRAME:
+
+            elif Sheetnames.TIGHTENING_TORQUES == sheetnames_relationships[sheetname]:
+                tightening_specifications = \
+                    TighteningSpecificationsSheet(worksheet=workbook[sheetname]).get_specification_elements()
+
+            elif Sheetnames.FRAME == sheetnames_relationships[sheetname]:
                 frame_elements = FrameSheet(worksheet=workbook[sheetname]).frame_elements
 
         self.motorcycle_model = MotorcycleModel(
-            model_name=filename[filename.rfind("/") + 1:filename.rfind(".")].rstrip().replace("FICHA ", ""),
+            model_name=model_name,
             generic_replacements=generic_replacements,
-            components_screws_tightening_torques=components_screws_tightening_torques,
-            electronic_elements=electronic_elements,
-            engine_sections=engine_sections,
-            frame_elements=frame_elements,
-            directory_name=directory,
+            tightening_specifications=tightening_specifications,
+            electronic=electronic_elements,
+            engine=engine_sections,
+            frame=frame_elements,
         )
+
